print("import: 'mpmath'")
import mpmath

print("import: 'mpmath.calculus'")
import mpmath.calculus

print("import: 'mpmath.functions'")
import mpmath.functions

print("import: 'mpmath.libmp'")
import mpmath.libmp

print("import: 'mpmath.matrices'")
import mpmath.matrices

print("import: 'mpmath.tests'")
import mpmath.tests

